// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: opentelemetry/proto/logs/v1/logs.proto
// Protobuf C++ Version: 7.35.1

#include "opentelemetry/proto/logs/v1/logs.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::opentelemetry::proto::logs::v1::LogsData
        {&::_pbi::kDescriptorMethods, &::descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto, /* tracker*/ nullptr,},
        // ::opentelemetry::proto::logs::v1::ResourceLogs
        {&::_pbi::kDescriptorMethods, &::descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto, /* tracker*/ nullptr,},
        // ::opentelemetry::proto::logs::v1::ScopeLogs
        {&::_pbi::kDescriptorMethods, &::descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto, /* tracker*/ nullptr,},
        // ::opentelemetry::proto::logs::v1::LogRecord
        {&::_pbi::kDescriptorMethods, &::descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace opentelemetry {
namespace proto {
namespace logs {
namespace v1 {
class LogRecord::_Internal {
 public:
  using HasBits = decltype(::std::declval<LogRecord>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(LogRecord, _impl_._has_bits_);
};

constexpr LogRecord::ParseTableT_ LogRecord::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(LogRecord, _impl_._has_bits_),
      0, // no _extensions_
      11, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294965256,  // skipmap
      offsetof(ParseTableT_, field_entries),
      10,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::LogRecord>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // fixed64 time_unix_nano = 1;
      {::_pbi::TcParser::FastF64S1,
       {9, 5, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.time_unix_nano_)}},
      // .opentelemetry.proto.logs.v1.SeverityNumber severity_number = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(LogRecord, _impl_.severity_number_), 6>(),
       {16, 6, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.severity_number_)}},
      // string severity_text = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.severity_text_)}},
      {::_pbi::TcParser::MiniParse, {}},
      // .opentelemetry.proto.common.v1.AnyValue body = 5;
      {::_pbi::TcParser::FastMtS1,
       {42, 4, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.body_)}},
      // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 6;
      {::_pbi::TcParser::FastMtR1,
       {50, 0, 1,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.attributes_)}},
      // uint32 dropped_attributes_count = 7;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(LogRecord, _impl_.dropped_attributes_count_), 7>(),
       {56, 7, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.dropped_attributes_count_)}},
      // fixed32 flags = 8;
      {::_pbi::TcParser::FastF32S1,
       {69, 9, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.flags_)}},
      // bytes trace_id = 9;
      {::_pbi::TcParser::FastBS1,
       {74, 2, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.trace_id_)}},
      // bytes span_id = 10;
      {::_pbi::TcParser::FastBS1,
       {82, 3, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.span_id_)}},
      // fixed64 observed_time_unix_nano = 11;
      {::_pbi::TcParser::FastF64S1,
       {89, 8, 0,
        PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.observed_time_unix_nano_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // fixed64 time_unix_nano = 1;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.time_unix_nano_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kFixed64)},
      // .opentelemetry.proto.logs.v1.SeverityNumber severity_number = 2;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.severity_number_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // string severity_text = 3;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.severity_text_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .opentelemetry.proto.common.v1.AnyValue body = 5;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.body_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 6;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.attributes_), _Internal::kHasBitsOffset + 0, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // uint32 dropped_attributes_count = 7;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.dropped_attributes_count_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // fixed32 flags = 8;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.flags_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kFixed32)},
      // bytes trace_id = 9;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.trace_id_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
      // bytes span_id = 10;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.span_id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
      // fixed64 observed_time_unix_nano = 11;
      {PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.observed_time_unix_nano_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kFixed64)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::common::v1::AnyValue>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::common::v1::AnyValue_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::common::v1::KeyValue>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::common::v1::KeyValue_globals_},
        #endif
    }},
    {{
      "\45\0\0\15\0\0\0\0\0\0\0\0\0\0\0\0"
      "opentelemetry.proto.logs.v1.LogRecord"
      "severity_text"
    }},
  };
}


inline constexpr LogRecord::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        attributes_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::LogRecord,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.attributes_)>()
         }
        ,
        severity_text_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        trace_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        span_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        body_{nullptr},
        time_unix_nano_{::uint64_t{0u}},
        severity_number_{static_cast< ::opentelemetry::proto::logs::v1::SeverityNumber >(0)},
        dropped_attributes_count_{0u},
        observed_time_unix_nano_{::uint64_t{0u}},
        flags_{0u} {}

template <typename>
constexpr LogRecord::LogRecord(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL LogRecord::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) LogRecord(arena);
}
constexpr auto LogRecord::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(LogRecord), alignof(LogRecord));
}
constexpr auto LogRecord::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &LogRecord::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<LogRecord>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &LogRecord::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<LogRecord>(), &LogRecord::ByteSizeLong,
              &LogRecord::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(LogRecord, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct LogRecordGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr LogRecordGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 LogRecord_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(LogRecord::InternalGenerateClassData_(
            _default, &LogRecord_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<LogRecord>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~LogRecordGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) LogRecord _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<LogRecord>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(LogRecordGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST LogRecordGlobalsTypeInternal LogRecord_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* LogRecord_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return LogRecord_globals_.GetClassData();
#else
  return LogRecord_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ScopeLogs::_Internal {
 public:
  using HasBits = decltype(::std::declval<ScopeLogs>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_._has_bits_);
};

constexpr ScopeLogs::ParseTableT_ ScopeLogs::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::ScopeLogs>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // .opentelemetry.proto.common.v1.InstrumentationScope scope = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 2, 0,
        PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_.scope_)}},
      // repeated .opentelemetry.proto.logs.v1.LogRecord log_records = 2;
      {::_pbi::TcParser::FastMtR1,
       {18, 0, 1,
        PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_.log_records_)}},
      // string schema_url = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_.schema_url_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .opentelemetry.proto.common.v1.InstrumentationScope scope = 1;
      {PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_.scope_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .opentelemetry.proto.logs.v1.LogRecord log_records = 2;
      {PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_.log_records_), _Internal::kHasBitsOffset + 0, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // string schema_url = 3;
      {PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_.schema_url_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::common::v1::InstrumentationScope>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::common::v1::InstrumentationScope_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::LogRecord>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::logs::v1::LogRecord_globals_},
        #endif
    }},
    {{
      "\45\0\0\12\0\0\0\0"
      "opentelemetry.proto.logs.v1.ScopeLogs"
      "schema_url"
    }},
  };
}


inline constexpr ScopeLogs::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        log_records_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::ScopeLogs,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_.log_records_)>()
         }
        ,
        schema_url_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        scope_{nullptr} {}

template <typename>
constexpr ScopeLogs::ScopeLogs(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ScopeLogs::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ScopeLogs(arena);
}
constexpr auto ScopeLogs::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ScopeLogs), alignof(ScopeLogs));
}
constexpr auto ScopeLogs::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ScopeLogs::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ScopeLogs>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ScopeLogs::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ScopeLogs>(), &ScopeLogs::ByteSizeLong,
              &ScopeLogs::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ScopeLogs, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ScopeLogsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ScopeLogsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ScopeLogs_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ScopeLogs::InternalGenerateClassData_(
            _default, &ScopeLogs_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ScopeLogs>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ScopeLogsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ScopeLogs _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ScopeLogs>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ScopeLogsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ScopeLogsGlobalsTypeInternal ScopeLogs_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ScopeLogs_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ScopeLogs_globals_.GetClassData();
#else
  return ScopeLogs_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ResourceLogs::_Internal {
 public:
  using HasBits = decltype(::std::declval<ResourceLogs>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_._has_bits_);
};

constexpr ResourceLogs::ParseTableT_ ResourceLogs::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::ResourceLogs>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // .opentelemetry.proto.resource.v1.Resource resource = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 2, 0,
        PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_.resource_)}},
      // repeated .opentelemetry.proto.logs.v1.ScopeLogs scope_logs = 2;
      {::_pbi::TcParser::FastMtR1,
       {18, 0, 1,
        PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_.scope_logs_)}},
      // string schema_url = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_.schema_url_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .opentelemetry.proto.resource.v1.Resource resource = 1;
      {PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_.resource_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .opentelemetry.proto.logs.v1.ScopeLogs scope_logs = 2;
      {PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_.scope_logs_), _Internal::kHasBitsOffset + 0, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // string schema_url = 3;
      {PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_.schema_url_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::resource::v1::Resource>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::resource::v1::Resource_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::ScopeLogs>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::logs::v1::ScopeLogs_globals_},
        #endif
    }},
    {{
      "\50\0\0\12\0\0\0\0"
      "opentelemetry.proto.logs.v1.ResourceLogs"
      "schema_url"
    }},
  };
}


inline constexpr ResourceLogs::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        scope_logs_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::ResourceLogs,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_.scope_logs_)>()
         }
        ,
        schema_url_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        resource_{nullptr} {}

template <typename>
constexpr ResourceLogs::ResourceLogs(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ResourceLogs::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ResourceLogs(arena);
}
constexpr auto ResourceLogs::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ResourceLogs), alignof(ResourceLogs));
}
constexpr auto ResourceLogs::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ResourceLogs::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ResourceLogs>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ResourceLogs::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ResourceLogs>(), &ResourceLogs::ByteSizeLong,
              &ResourceLogs::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ResourceLogs, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ResourceLogsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ResourceLogsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ResourceLogs_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ResourceLogs::InternalGenerateClassData_(
            _default, &ResourceLogs_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ResourceLogs>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ResourceLogsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ResourceLogs _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ResourceLogs>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ResourceLogsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ResourceLogsGlobalsTypeInternal ResourceLogs_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ResourceLogs_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ResourceLogs_globals_.GetClassData();
#else
  return ResourceLogs_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class LogsData::_Internal {
 public:
  using HasBits = decltype(::std::declval<LogsData>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(LogsData, _impl_._has_bits_);
};

constexpr LogsData::ParseTableT_ LogsData::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(LogsData, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::LogsData>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated .opentelemetry.proto.logs.v1.ResourceLogs resource_logs = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(LogsData, _impl_.resource_logs_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .opentelemetry.proto.logs.v1.ResourceLogs resource_logs = 1;
      {PROTOBUF_FIELD_OFFSET(LogsData, _impl_.resource_logs_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::opentelemetry::proto::logs::v1::ResourceLogs>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::opentelemetry::proto::logs::v1::ResourceLogs_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr LogsData::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        resource_logs_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::LogsData,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogsData, _impl_.resource_logs_)>()
         }
     {}

template <typename>
constexpr LogsData::LogsData(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL LogsData::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) LogsData(arena);
}
constexpr auto LogsData::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(LogsData), alignof(LogsData));
}
constexpr auto LogsData::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &LogsData::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<LogsData>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &LogsData::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<LogsData>(), &LogsData::ByteSizeLong,
              &LogsData::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(LogsData, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct LogsDataGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr LogsDataGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 LogsData_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(LogsData::InternalGenerateClassData_(
            _default, &LogsData_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<LogsData>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~LogsDataGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) LogsData _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<LogsData>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(LogsDataGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST LogsDataGlobalsTypeInternal LogsData_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* LogsData_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return LogsData_globals_.GetClassData();
#else
  return LogsData_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace logs
}  // namespace proto
}  // namespace opentelemetry
static const ::_pb::EnumDescriptor* PROTOBUF_NONNULL
    file_level_enum_descriptors_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto[2];
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto = nullptr;
const ::uint32_t
    TableStruct_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogsData, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogsData, _impl_.resource_logs_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_.resource_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_.scope_logs_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_.schema_url_),
        2,
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_.scope_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_.log_records_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_.schema_url_),
        2,
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_._has_bits_),
        13, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.time_unix_nano_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.observed_time_unix_nano_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.severity_number_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.severity_text_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.body_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.attributes_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.dropped_attributes_count_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.flags_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.trace_id_),
        PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.span_id_),
        5,
        8,
        6,
        1,
        4,
        0,
        7,
        9,
        2,
        3,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::opentelemetry::proto::logs::v1::LogsData)},
        {5, sizeof(::opentelemetry::proto::logs::v1::ResourceLogs)},
        {14, sizeof(::opentelemetry::proto::logs::v1::ScopeLogs)},
        {23, sizeof(::opentelemetry::proto::logs::v1::LogRecord)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::opentelemetry::proto::logs::v1::LogsData_globals_,
        &::opentelemetry::proto::logs::v1::ResourceLogs_globals_,
        &::opentelemetry::proto::logs::v1::ScopeLogs_globals_,
        &::opentelemetry::proto::logs::v1::LogRecord_globals_,
};
const char descriptor_table_protodef_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n&opentelemetry/proto/logs/v1/logs.proto"
    "\022\033opentelemetry.proto.logs.v1\032*opentelem"
    "etry/proto/common/v1/common.proto\032.opent"
    "elemetry/proto/resource/v1/resource.prot"
    "o\"L\n\010LogsData\022@\n\rresource_logs\030\001 \003(\0132).o"
    "pentelemetry.proto.logs.v1.ResourceLogs\""
    "\243\001\n\014ResourceLogs\022;\n\010resource\030\001 \001(\0132).ope"
    "ntelemetry.proto.resource.v1.Resource\022:\n"
    "\nscope_logs\030\002 \003(\0132&.opentelemetry.proto."
    "logs.v1.ScopeLogs\022\022\n\nschema_url\030\003 \001(\tJ\006\010"
    "\350\007\020\351\007\"\240\001\n\tScopeLogs\022B\n\005scope\030\001 \001(\01323.ope"
    "ntelemetry.proto.common.v1.Instrumentati"
    "onScope\022;\n\013log_records\030\002 \003(\0132&.opentelem"
    "etry.proto.logs.v1.LogRecord\022\022\n\nschema_u"
    "rl\030\003 \001(\t\"\357\002\n\tLogRecord\022\026\n\016time_unix_nano"
    "\030\001 \001(\006\022\037\n\027observed_time_unix_nano\030\013 \001(\006\022"
    "D\n\017severity_number\030\002 \001(\0162+.opentelemetry"
    ".proto.logs.v1.SeverityNumber\022\025\n\rseverit"
    "y_text\030\003 \001(\t\0225\n\004body\030\005 \001(\0132\'.opentelemet"
    "ry.proto.common.v1.AnyValue\022;\n\nattribute"
    "s\030\006 \003(\0132\'.opentelemetry.proto.common.v1."
    "KeyValue\022 \n\030dropped_attributes_count\030\007 \001"
    "(\r\022\r\n\005flags\030\010 \001(\007\022\020\n\010trace_id\030\t \001(\014\022\017\n\007s"
    "pan_id\030\n \001(\014J\004\010\004\020\005*\303\005\n\016SeverityNumber\022\037\n"
    "\033SEVERITY_NUMBER_UNSPECIFIED\020\000\022\031\n\025SEVERI"
    "TY_NUMBER_TRACE\020\001\022\032\n\026SEVERITY_NUMBER_TRA"
    "CE2\020\002\022\032\n\026SEVERITY_NUMBER_TRACE3\020\003\022\032\n\026SEV"
    "ERITY_NUMBER_TRACE4\020\004\022\031\n\025SEVERITY_NUMBER"
    "_DEBUG\020\005\022\032\n\026SEVERITY_NUMBER_DEBUG2\020\006\022\032\n\026"
    "SEVERITY_NUMBER_DEBUG3\020\007\022\032\n\026SEVERITY_NUM"
    "BER_DEBUG4\020\010\022\030\n\024SEVERITY_NUMBER_INFO\020\t\022\031"
    "\n\025SEVERITY_NUMBER_INFO2\020\n\022\031\n\025SEVERITY_NU"
    "MBER_INFO3\020\013\022\031\n\025SEVERITY_NUMBER_INFO4\020\014\022"
    "\030\n\024SEVERITY_NUMBER_WARN\020\r\022\031\n\025SEVERITY_NU"
    "MBER_WARN2\020\016\022\031\n\025SEVERITY_NUMBER_WARN3\020\017\022"
    "\031\n\025SEVERITY_NUMBER_WARN4\020\020\022\031\n\025SEVERITY_N"
    "UMBER_ERROR\020\021\022\032\n\026SEVERITY_NUMBER_ERROR2\020"
    "\022\022\032\n\026SEVERITY_NUMBER_ERROR3\020\023\022\032\n\026SEVERIT"
    "Y_NUMBER_ERROR4\020\024\022\031\n\025SEVERITY_NUMBER_FAT"
    "AL\020\025\022\032\n\026SEVERITY_NUMBER_FATAL2\020\026\022\032\n\026SEVE"
    "RITY_NUMBER_FATAL3\020\027\022\032\n\026SEVERITY_NUMBER_"
    "FATAL4\020\030*Y\n\016LogRecordFlags\022\037\n\033LOG_RECORD"
    "_FLAGS_DO_NOT_USE\020\000\022&\n!LOG_RECORD_FLAGS_"
    "TRACE_FLAGS_MASK\020\377\001Bs\n\036io.opentelemetry."
    "proto.logs.v1B\tLogsProtoP\001Z&go.opentelem"
    "etry.io/proto/otlp/logs/v1\252\002\033OpenTelemet"
    "ry.Proto.Logs.V1b\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto_deps[2] = {
        &::descriptor_table_opentelemetry_2fproto_2fcommon_2fv1_2fcommon_2eproto,
        &::descriptor_table_opentelemetry_2fproto_2fresource_2fv1_2fresource_2eproto,
};
static ::absl::once_flag descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto = {
    false,
    false,
    1864,
    descriptor_table_protodef_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
    "opentelemetry/proto/logs/v1/logs.proto",
    &descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto_once,
    descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto_deps,
    2,
    4,
    schemas,
    file_message_globals,
    TableStruct_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto::offsets,
    file_level_enum_descriptors_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
    file_level_service_descriptors_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto,
};
namespace opentelemetry {
namespace proto {
namespace logs {
namespace v1 {
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
SeverityNumber_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto);
  return file_level_enum_descriptors_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto[0];
}
PROTOBUF_CONSTINIT const uint32_t SeverityNumber_internal_data_[] = {
    1638400u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
LogRecordFlags_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto);
  return file_level_enum_descriptors_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto[1];
}
PROTOBUF_CONSTINIT const uint32_t LogRecordFlags_internal_data_[] = {
    65536u, 65536u, 255u, };
// ===================================================================

LogsData::LogsData(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, LogsData_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opentelemetry.proto.logs.v1.LogsData)
}
PROTOBUF_NDEBUG_INLINE LogsData::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opentelemetry::proto::logs::v1::LogsData& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        resource_logs_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::opentelemetry::proto::logs::v1::LogsData,
              PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogsData, _impl_.resource_logs_)>()
          , from.resource_logs_
        }
     {}

LogsData::LogsData(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const LogsData& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, LogsData_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  LogsData* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:opentelemetry.proto.logs.v1.LogsData)
}
PROTOBUF_NDEBUG_INLINE LogsData::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        resource_logs_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::LogsData,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogsData, _impl_.resource_logs_)>()
         }
     {}

inline void LogsData::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
LogsData::~LogsData() {
  // @@protoc_insertion_point(destructor:opentelemetry.proto.logs.v1.LogsData)
  SharedDtor(*this);
}
inline void LogsData::SharedDtor(MessageLite& self) {
  LogsData& this_ = static_cast<LogsData&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull LogsData_class_data_ =
        LogsData::InternalGenerateClassData_(LogsData_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
LogsData::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&LogsData_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(LogsData_class_data_.tc_table);
  return LogsData_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
LogsData::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&LogsData_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&LogsData_globals_));
  return LogsData_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const LogsData::ParseTableT_
    LogsData::_table_ =
        LogsData::InternalGenerateParseTable_(LogsData_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void LogsData::Clear() {
// @@protoc_insertion_point(message_clear_start:opentelemetry.proto.logs.v1.LogsData)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.resource_logs_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL LogsData::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const LogsData& this_ = static_cast<const LogsData&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL LogsData::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const LogsData& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opentelemetry.proto.logs.v1.LogsData)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .opentelemetry.proto.logs.v1.ResourceLogs resource_logs = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_resource_logs_size());
         i < n; i++) {
      const auto& repfield = this_._internal_resource_logs().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opentelemetry.proto.logs.v1.LogsData)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t LogsData::ByteSizeLong(const MessageLite& base) {
  const LogsData& this_ = static_cast<const LogsData&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t LogsData::ByteSizeLong() const {
  const LogsData& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opentelemetry.proto.logs.v1.LogsData)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .opentelemetry.proto.logs.v1.ResourceLogs resource_logs = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_resource_logs_size();
      for (const auto& msg : this_._internal_resource_logs()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void LogsData::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<LogsData*>(&to_msg);
  auto& from = static_cast<const LogsData&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opentelemetry.proto.logs.v1.LogsData)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_resource_logs()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_resource_logs());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void LogsData::CopyFrom(const LogsData& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:opentelemetry.proto.logs.v1.LogsData)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void LogsData::InternalSwap(LogsData* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.resource_logs_.InternalSwap(&other->_impl_.resource_logs_);
}

::google::protobuf::Metadata LogsData::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void ResourceLogs::clear_resource() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.resource_ != nullptr) _impl_.resource_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
ResourceLogs::ResourceLogs(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ResourceLogs_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opentelemetry.proto.logs.v1.ResourceLogs)
}
PROTOBUF_NDEBUG_INLINE ResourceLogs::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opentelemetry::proto::logs::v1::ResourceLogs& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        scope_logs_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::opentelemetry::proto::logs::v1::ResourceLogs,
              PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_.scope_logs_)>()
          , from.scope_logs_
        }
        ,
        schema_url_(arena, from.schema_url_) {}

ResourceLogs::ResourceLogs(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ResourceLogs& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ResourceLogs_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ResourceLogs* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.resource_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.resource_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:opentelemetry.proto.logs.v1.ResourceLogs)
}
PROTOBUF_NDEBUG_INLINE ResourceLogs::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        scope_logs_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::ResourceLogs,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ResourceLogs, _impl_.scope_logs_)>()
         }
        ,
        schema_url_(arena) {}

inline void ResourceLogs::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.resource_ = {};
}
ResourceLogs::~ResourceLogs() {
  // @@protoc_insertion_point(destructor:opentelemetry.proto.logs.v1.ResourceLogs)
  SharedDtor(*this);
}
inline void ResourceLogs::SharedDtor(MessageLite& self) {
  ResourceLogs& this_ = static_cast<ResourceLogs&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.schema_url_.Destroy();
  delete this_._impl_.resource_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ResourceLogs_class_data_ =
        ResourceLogs::InternalGenerateClassData_(ResourceLogs_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ResourceLogs::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ResourceLogs_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ResourceLogs_class_data_.tc_table);
  return ResourceLogs_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ResourceLogs::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ResourceLogs_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ResourceLogs_globals_));
  return ResourceLogs_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ResourceLogs::ParseTableT_
    ResourceLogs::_table_ =
        ResourceLogs::InternalGenerateParseTable_(ResourceLogs_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ResourceLogs::Clear() {
// @@protoc_insertion_point(message_clear_start:opentelemetry.proto.logs.v1.ResourceLogs)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.scope_logs_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.schema_url_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.resource_ != nullptr);
      _impl_.resource_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ResourceLogs::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ResourceLogs& this_ = static_cast<const ResourceLogs&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ResourceLogs::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ResourceLogs& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opentelemetry.proto.logs.v1.ResourceLogs)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .opentelemetry.proto.resource.v1.Resource resource = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.resource_, this_._impl_.resource_->GetCachedSize(), target,
        stream);
  }

  // repeated .opentelemetry.proto.logs.v1.ScopeLogs scope_logs = 2;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_scope_logs_size());
         i < n; i++) {
      const auto& repfield = this_._internal_scope_logs().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              2, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // string schema_url = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_schema_url().empty()) {
      const ::std::string& _s = this_._internal_schema_url();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opentelemetry.proto.logs.v1.ResourceLogs.schema_url");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opentelemetry.proto.logs.v1.ResourceLogs)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ResourceLogs::ByteSizeLong(const MessageLite& base) {
  const ResourceLogs& this_ = static_cast<const ResourceLogs&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ResourceLogs::ByteSizeLong() const {
  const ResourceLogs& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opentelemetry.proto.logs.v1.ResourceLogs)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // repeated .opentelemetry.proto.logs.v1.ScopeLogs scope_logs = 2;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_scope_logs_size();
      for (const auto& msg : this_._internal_scope_logs()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // string schema_url = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_schema_url().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_schema_url());
      }
    }
    // .opentelemetry.proto.resource.v1.Resource resource = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.resource_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ResourceLogs::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ResourceLogs*>(&to_msg);
  auto& from = static_cast<const ResourceLogs&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opentelemetry.proto.logs.v1.ResourceLogs)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_scope_logs()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_scope_logs());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_schema_url().empty()) {
        _this->_internal_set_schema_url(from._internal_schema_url());
      } else {
        if (_this->_impl_.schema_url_.IsDefault()) {
          _this->_internal_set_schema_url("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.resource_ != nullptr);
      if (_this->_impl_.resource_ == nullptr) {
        _this->_impl_.resource_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.resource_);
      } else {
        _this->_impl_.resource_->MergeFrom(*from._impl_.resource_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ResourceLogs::CopyFrom(const ResourceLogs& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:opentelemetry.proto.logs.v1.ResourceLogs)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ResourceLogs::InternalSwap(ResourceLogs* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.scope_logs_.InternalSwap(&other->_impl_.scope_logs_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.schema_url_, &other->_impl_.schema_url_, arena);
  swap(_impl_.resource_, other->_impl_.resource_);
}

::google::protobuf::Metadata ResourceLogs::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void ScopeLogs::clear_scope() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.scope_ != nullptr) _impl_.scope_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
ScopeLogs::ScopeLogs(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ScopeLogs_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opentelemetry.proto.logs.v1.ScopeLogs)
}
PROTOBUF_NDEBUG_INLINE ScopeLogs::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opentelemetry::proto::logs::v1::ScopeLogs& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        log_records_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::opentelemetry::proto::logs::v1::ScopeLogs,
              PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_.log_records_)>()
          , from.log_records_
        }
        ,
        schema_url_(arena, from.schema_url_) {}

ScopeLogs::ScopeLogs(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ScopeLogs& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ScopeLogs_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ScopeLogs* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.scope_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.scope_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:opentelemetry.proto.logs.v1.ScopeLogs)
}
PROTOBUF_NDEBUG_INLINE ScopeLogs::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        log_records_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::ScopeLogs,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::ScopeLogs, _impl_.log_records_)>()
         }
        ,
        schema_url_(arena) {}

inline void ScopeLogs::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.scope_ = {};
}
ScopeLogs::~ScopeLogs() {
  // @@protoc_insertion_point(destructor:opentelemetry.proto.logs.v1.ScopeLogs)
  SharedDtor(*this);
}
inline void ScopeLogs::SharedDtor(MessageLite& self) {
  ScopeLogs& this_ = static_cast<ScopeLogs&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.schema_url_.Destroy();
  delete this_._impl_.scope_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ScopeLogs_class_data_ =
        ScopeLogs::InternalGenerateClassData_(ScopeLogs_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ScopeLogs::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ScopeLogs_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ScopeLogs_class_data_.tc_table);
  return ScopeLogs_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ScopeLogs::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ScopeLogs_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ScopeLogs_globals_));
  return ScopeLogs_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ScopeLogs::ParseTableT_
    ScopeLogs::_table_ =
        ScopeLogs::InternalGenerateParseTable_(ScopeLogs_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ScopeLogs::Clear() {
// @@protoc_insertion_point(message_clear_start:opentelemetry.proto.logs.v1.ScopeLogs)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.log_records_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.schema_url_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.scope_ != nullptr);
      _impl_.scope_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ScopeLogs::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ScopeLogs& this_ = static_cast<const ScopeLogs&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ScopeLogs::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ScopeLogs& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opentelemetry.proto.logs.v1.ScopeLogs)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .opentelemetry.proto.common.v1.InstrumentationScope scope = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.scope_, this_._impl_.scope_->GetCachedSize(), target,
        stream);
  }

  // repeated .opentelemetry.proto.logs.v1.LogRecord log_records = 2;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_log_records_size());
         i < n; i++) {
      const auto& repfield = this_._internal_log_records().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              2, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // string schema_url = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_schema_url().empty()) {
      const ::std::string& _s = this_._internal_schema_url();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opentelemetry.proto.logs.v1.ScopeLogs.schema_url");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opentelemetry.proto.logs.v1.ScopeLogs)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ScopeLogs::ByteSizeLong(const MessageLite& base) {
  const ScopeLogs& this_ = static_cast<const ScopeLogs&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ScopeLogs::ByteSizeLong() const {
  const ScopeLogs& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opentelemetry.proto.logs.v1.ScopeLogs)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // repeated .opentelemetry.proto.logs.v1.LogRecord log_records = 2;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_log_records_size();
      for (const auto& msg : this_._internal_log_records()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // string schema_url = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_schema_url().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_schema_url());
      }
    }
    // .opentelemetry.proto.common.v1.InstrumentationScope scope = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.scope_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ScopeLogs::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ScopeLogs*>(&to_msg);
  auto& from = static_cast<const ScopeLogs&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opentelemetry.proto.logs.v1.ScopeLogs)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_log_records()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_log_records());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_schema_url().empty()) {
        _this->_internal_set_schema_url(from._internal_schema_url());
      } else {
        if (_this->_impl_.schema_url_.IsDefault()) {
          _this->_internal_set_schema_url("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.scope_ != nullptr);
      if (_this->_impl_.scope_ == nullptr) {
        _this->_impl_.scope_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.scope_);
      } else {
        _this->_impl_.scope_->MergeFrom(*from._impl_.scope_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ScopeLogs::CopyFrom(const ScopeLogs& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:opentelemetry.proto.logs.v1.ScopeLogs)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ScopeLogs::InternalSwap(ScopeLogs* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.log_records_.InternalSwap(&other->_impl_.log_records_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.schema_url_, &other->_impl_.schema_url_, arena);
  swap(_impl_.scope_, other->_impl_.scope_);
}

::google::protobuf::Metadata ScopeLogs::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void LogRecord::clear_body() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.body_ != nullptr) _impl_.body_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
void LogRecord::clear_attributes() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.attributes_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
LogRecord::LogRecord(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, LogRecord_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opentelemetry.proto.logs.v1.LogRecord)
}
PROTOBUF_NDEBUG_INLINE LogRecord::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opentelemetry::proto::logs::v1::LogRecord& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        attributes_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::opentelemetry::proto::logs::v1::LogRecord,
              PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.attributes_)>()
          , from.attributes_
        }
        ,
        severity_text_(arena, from.severity_text_),
        trace_id_(arena, from.trace_id_),
        span_id_(arena, from.span_id_) {}

LogRecord::LogRecord(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const LogRecord& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, LogRecord_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  LogRecord* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.body_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.body_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, time_unix_nano_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, time_unix_nano_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, time_unix_nano_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:opentelemetry.proto.logs.v1.LogRecord)
}
PROTOBUF_NDEBUG_INLINE LogRecord::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        attributes_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::opentelemetry::proto::logs::v1::LogRecord,
            PROTOBUF_FIELD_OFFSET(::opentelemetry::proto::logs::v1::LogRecord, _impl_.attributes_)>()
         }
        ,
        severity_text_(arena),
        trace_id_(arena),
        span_id_(arena) {}

inline void LogRecord::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, body_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, body_) +
               sizeof(Impl_::flags_));
}
LogRecord::~LogRecord() {
  // @@protoc_insertion_point(destructor:opentelemetry.proto.logs.v1.LogRecord)
  SharedDtor(*this);
}
inline void LogRecord::SharedDtor(MessageLite& self) {
  LogRecord& this_ = static_cast<LogRecord&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.severity_text_.Destroy();
  this_._impl_.trace_id_.Destroy();
  this_._impl_.span_id_.Destroy();
  delete this_._impl_.body_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull LogRecord_class_data_ =
        LogRecord::InternalGenerateClassData_(LogRecord_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
LogRecord::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&LogRecord_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(LogRecord_class_data_.tc_table);
  return LogRecord_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
LogRecord::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&LogRecord_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&LogRecord_globals_));
  return LogRecord_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const LogRecord::ParseTableT_
    LogRecord::_table_ =
        LogRecord::InternalGenerateParseTable_(LogRecord_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void LogRecord::Clear() {
// @@protoc_insertion_point(message_clear_start:opentelemetry.proto.logs.v1.LogRecord)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.attributes_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.severity_text_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.trace_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.span_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.body_ != nullptr);
      _impl_.body_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000e0U)) {
    ::memset(&_impl_.time_unix_nano_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.dropped_attributes_count_) -
        reinterpret_cast<char*>(&_impl_.time_unix_nano_)) + sizeof(_impl_.dropped_attributes_count_));
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    ::memset(&_impl_.observed_time_unix_nano_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.observed_time_unix_nano_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL LogRecord::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const LogRecord& this_ = static_cast<const LogRecord&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL LogRecord::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const LogRecord& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opentelemetry.proto.logs.v1.LogRecord)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // fixed64 time_unix_nano = 1;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_time_unix_nano() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteFixed64ToArray(
          1, this_._internal_time_unix_nano(), target);
    }
  }

  // .opentelemetry.proto.logs.v1.SeverityNumber severity_number = 2;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_severity_number() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          2, this_._internal_severity_number(), target);
    }
  }

  // string severity_text = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_severity_text().empty()) {
      const ::std::string& _s = this_._internal_severity_text();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opentelemetry.proto.logs.v1.LogRecord.severity_text");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // .opentelemetry.proto.common.v1.AnyValue body = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        5, *this_._impl_.body_, this_._impl_.body_->GetCachedSize(), target,
        stream);
  }

  // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 6;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_attributes_size());
         i < n; i++) {
      const auto& repfield = this_._internal_attributes().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              6, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // uint32 dropped_attributes_count = 7;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_dropped_attributes_count() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          7, this_._internal_dropped_attributes_count(), target);
    }
  }

  // fixed32 flags = 8;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteFixed32ToArray(
          8, this_._internal_flags(), target);
    }
  }

  // bytes trace_id = 9;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_trace_id().empty()) {
      const ::std::string& _s = this_._internal_trace_id();
      target = stream->WriteBytesMaybeAliased(9, _s, target);
    }
  }

  // bytes span_id = 10;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_span_id().empty()) {
      const ::std::string& _s = this_._internal_span_id();
      target = stream->WriteBytesMaybeAliased(10, _s, target);
    }
  }

  // fixed64 observed_time_unix_nano = 11;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_observed_time_unix_nano() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteFixed64ToArray(
          11, this_._internal_observed_time_unix_nano(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opentelemetry.proto.logs.v1.LogRecord)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t LogRecord::ByteSizeLong(const MessageLite& base) {
  const LogRecord& this_ = static_cast<const LogRecord&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t LogRecord::ByteSizeLong() const {
  const LogRecord& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opentelemetry.proto.logs.v1.LogRecord)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 6;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_attributes_size();
      for (const auto& msg : this_._internal_attributes()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // string severity_text = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_severity_text().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_severity_text());
      }
    }
    // bytes trace_id = 9;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_trace_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                        this_._internal_trace_id());
      }
    }
    // bytes span_id = 10;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_span_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                        this_._internal_span_id());
      }
    }
    // .opentelemetry.proto.common.v1.AnyValue body = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.body_);
    }
    // fixed64 time_unix_nano = 1;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_time_unix_nano() != 0) {
        total_size += 9;
      }
    }
    // .opentelemetry.proto.logs.v1.SeverityNumber severity_number = 2;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_severity_number() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_severity_number());
      }
    }
    // uint32 dropped_attributes_count = 7;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_dropped_attributes_count() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_dropped_attributes_count());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    // fixed64 observed_time_unix_nano = 11;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_observed_time_unix_nano() != 0) {
        total_size += 9;
      }
    }
    // fixed32 flags = 8;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (this_._internal_flags() != 0) {
        total_size += 5;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void LogRecord::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<LogRecord*>(&to_msg);
  auto& from = static_cast<const LogRecord&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opentelemetry.proto.logs.v1.LogRecord)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_attributes()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_attributes());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_severity_text().empty()) {
        _this->_internal_set_severity_text(from._internal_severity_text());
      } else {
        if (_this->_impl_.severity_text_.IsDefault()) {
          _this->_internal_set_severity_text("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_trace_id().empty()) {
        _this->_internal_set_trace_id(from._internal_trace_id());
      } else {
        if (_this->_impl_.trace_id_.IsDefault()) {
          _this->_internal_set_trace_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_span_id().empty()) {
        _this->_internal_set_span_id(from._internal_span_id());
      } else {
        if (_this->_impl_.span_id_.IsDefault()) {
          _this->_internal_set_span_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.body_ != nullptr);
      if (_this->_impl_.body_ == nullptr) {
        _this->_impl_.body_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.body_);
      } else {
        _this->_impl_.body_->MergeFrom(*from._impl_.body_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_time_unix_nano() != 0) {
        _this->_impl_.time_unix_nano_ = from._impl_.time_unix_nano_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_severity_number() != 0) {
        _this->_impl_.severity_number_ = from._impl_.severity_number_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_dropped_attributes_count() != 0) {
        _this->_impl_.dropped_attributes_count_ = from._impl_.dropped_attributes_count_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_observed_time_unix_nano() != 0) {
        _this->_impl_.observed_time_unix_nano_ = from._impl_.observed_time_unix_nano_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void LogRecord::CopyFrom(const LogRecord& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:opentelemetry.proto.logs.v1.LogRecord)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void LogRecord::InternalSwap(LogRecord* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.attributes_.InternalSwap(&other->_impl_.attributes_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.severity_text_, &other->_impl_.severity_text_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.trace_id_, &other->_impl_.trace_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.span_id_, &other->_impl_.span_id_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.flags_)
      + sizeof(LogRecord::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(LogRecord, _impl_.body_)>(
          reinterpret_cast<char*>(&_impl_.body_),
          reinterpret_cast<char*>(&other->_impl_.body_));
}

::google::protobuf::Metadata LogRecord::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace logs
}  // namespace proto
}  // namespace opentelemetry
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_opentelemetry_2fproto_2flogs_2fv1_2flogs_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
